@@ -4,11 +4,12 @@ from .autocompletion import (
     get_installed_package,
     get_official_package,
 )
+from .compat import argument
 from .customcommand import CustomCommand
 from .option import OptionEatAll
 from .utils import param2lowercase
 
 __all__ = [
     'get_downstream_package', 'get_installed_package', 'get_official_package',
-    'OptionEatAll', 'CustomCommand', 'param2lowercase'
+    'OptionEatAll', 'CustomCommand', 'param2lowercase', 'argument'
 ]
